@@ -3,13 +3,13 @@ from pydantic import (
     HttpUrl, root_validator
 )
 
-from typing import Optional, List, Union
+from typing import Optional, List
 
 from ..generics import Image
 
 
 class BatchPredictionPreRunRequest_MetaField(BaseModel):
-    webhooks: Optional[Union[List[HttpUrl], HttpUrl]]
+    webhooks: Optional[HttpUrl]
 
 
 class BatchPredictionPreRunRequest(BaseModel):
